@@ -3,22 +3,16 @@
 //!
 //! All errors will be converted to RucError.
 //!
-use lazy_static::lazy_static;
+use once_cell::sync::Lazy;
 use std::sync::Mutex;
 use std::{
     collections::HashSet,
-    env,
     error::Error,
     fmt::{Debug, Display},
 };
 
-lazy_static! {
-    // avoid out-of-order printing
-    static ref LOG_LK: Mutex<()> = Mutex::new(());
-    static ref RUC_OUT: bool = env::var("RUC_OUT")
-                .map(|_str|true)
-                .unwrap_or_else(|_|false);
-}
+// avoid out-of-order printing
+static LOG_LK: Lazy<Mutex<()>> = Lazy::new(|| Mutex::new(()));
 
 /// Custom Result
 pub type Result<T> = std::result::Result<T, Box<dyn RucError>>;
@@ -166,12 +160,7 @@ pub trait RucError: Display + Debug + Send {
     #[inline(always)]
     fn print(&self, prefix: Option<&str>) {
         if LOG_LK.lock().is_ok() {
-            match &*RUC_OUT {
-                true => {
-                    eprintln!("{}", self.generate_log(prefix));
-                }
-                false => {}
-            }
+            eprintln!("{}", self.generate_log(prefix));
         }
     }
 
